summaryrefslogtreecommitdiff
path: root/Tools/scripts
diff options
context:
space:
mode:
authorYury Selivanov <yselivanov@sprymix.com>2015-07-03 01:04:23 -0400
committerYury Selivanov <yselivanov@sprymix.com>2015-07-03 01:04:23 -0400
commit1f0eea05f78b032be72ee5b5787421acef61588d (patch)
treedf649dbdcb14e9a2afce0d6e4629439dd72e1421 /Tools/scripts
parent4c0dd9f7ff8d58c2da9cccd1ca1ad7ee96e29ce1 (diff)
downloadcpython-1f0eea05f78b032be72ee5b5787421acef61588d.tar.gz
Issue #19235: Add new RecursionError exception. Patch by Georg Brandl.
Diffstat (limited to 'Tools/scripts')
-rwxr-xr-xTools/scripts/find_recursionlimit.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Tools/scripts/find_recursionlimit.py b/Tools/scripts/find_recursionlimit.py
index 1171146421..b2842a62ef 100755
--- a/Tools/scripts/find_recursionlimit.py
+++ b/Tools/scripts/find_recursionlimit.py
@@ -92,7 +92,7 @@ def test_cpickle(_cache={}):
def test_compiler_recursion():
# The compiler uses a scaling factor to support additional levels
# of recursion. This is a sanity check of that scaling to ensure
# it still raises RuntimeError even at higher recursion limits
compile("()" * (10 * sys.getrecursionlimit()), "<single>", "single")
def check_limit(n, test_func_name):
@@ -107,7 +107,7 @@ def check_limit(n, test_func_name):
# AttributeError can be raised because of the way e.g. PyDict_GetItem()
# silences all exceptions and returns NULL, which is usually interpreted
# as "missing attribute".
- except (RuntimeError, AttributeError):
+ except (RecursionError, AttributeError):
pass
else:
print("Yikes!")
@@ -92,7 +92,7 @@ def test_cpickle(_cache={}):
# The compiler uses a scaling factor to support additional levels
# of recursion. This is a sanity check of that scaling to ensure
- # it still raises RuntimeError even at higher recursion limits
+ # it still raises RecursionError even at higher recursion limits
compile("()" * (10 * sys.getrecursionlimit()), "<single>", "single")
def check_limit(n, test_func_name):